pilas.fisica

Package pilas :: Module fisica |
[hide private]
[frames] | no frames]

# Module fisica

source code

Classes | [hide private]
| Tmp
| contact_listener
| Fisica Representa un simulador de mundo fisico, usando la biblioteca Box2D (version 2.1).
| FisicaDeshabilitada Representa a un motor de física que no realiza acciones, y solo se habilita si box2d no funciona en el equipo.
| Figura Representa un figura que simula un cuerpo fisico.
| Circulo Representa un cuerpo de circulo.
| Rectangulo Representa un rectángulo que puede colisionar con otras figuras.
| Poligono Representa un cuerpo poligonal.
| ConstanteDeMovimiento Representa una constante de movimiento para el mouse.
| ConstanteDeDistancia Representa una distancia fija entre dos figuras.
| ObjetosContactListener Gestiona las colisiones de los objetos para ejecutar funcionés.

Functions | [hide private]
convertir_a_metros(valor) Convierte una magnitid de pixels a metros. | source code
convertir_a_pixels(valor) Convierte una magnitud de metros a pixels. | source code
crear_motor_fisica(area, gravedad) Genera el motor de física Box2D. | source code
obtener_version() Obtiene la versión de la biblioteca Box2D | source code
definir_gravedad(x, y) Define la gravedad del motor de física. | source code

Variables | [hide private]
| PPM = `30`
| __enabled__ = `False`
| __package__ = ``'``pilas``'``

Function Details | [hide private]

### crear_motor_fisica(area, gravedad) | source code
Genera el motor de física Box2D. :param area: El area de juego. :param gravedad: La gravedad del escenario.

### definir_gravedad(x, y) | source code
Define la gravedad del motor de física. :param x: Aceleración horizontal. :param y: Aceleración vertical.